@@ -1,4 +1,3 @@
-#!/usr/bin/perl
 # JSON.pm 
 # Copyright (c) 2007 Jonathan Rockway <jrockway@cpan.org>
 package Angerwhale::View::Feed::JSON;
@@ -6,16 +5,15 @@ package Angerwhale::View::Feed::JSON;
 use strict;
 use warnings;
 use base qw(Angerwhale::View::Feed Catalyst::View);
+use JSON;
 
 sub process {
     my ( $self, $c ) = @_;
     my @items = $self->prepare_items($c);
 
     my $stash = $c->stash;
-    $c->{stash} = {};
-    $c->stash->{items} = [@items];
-    $c->forward('View::JSON');
-    $c->{stash} = $stash;
+    $c->res->content_type('application/json');
+    $c->res->body(objToJson([@items]));
 }
 
 1;
